"use strict";
var minimatch = require("minimatch");
var constants = require("../constants");
var path = require("path");
var ProjectFilesProvider = (function () {
    function ProjectFilesProvider($platformsData, $projectData) {
        this.$platformsData = $platformsData;
        this.$projectData = $projectData;
    }
    ProjectFilesProvider.prototype.mapFilePath = function (filePath, platform) {
        var platformData = this.$platformsData.getPlatformData(platform.toLowerCase());
        var projectFilesPath = path.join(platformData.appDestinationDirectoryPath, constants.APP_FOLDER_NAME);
        var mappedFilePath = path.join(projectFilesPath, path.relative(path.join(this.$projectData.projectDir, constants.APP_FOLDER_NAME), filePath));
        var appResourcesDirectoryPath = path.join(constants.APP_FOLDER_NAME, constants.APP_RESOURCES_FOLDER_NAME);
        var platformSpecificAppResourcesDirectoryPath = path.join(appResourcesDirectoryPath, platformData.normalizedPlatformName);
        if (filePath.indexOf(appResourcesDirectoryPath) > -1 && filePath.indexOf(platformSpecificAppResourcesDirectoryPath) === -1) {
            return null;
        }
        if (filePath.indexOf(platformSpecificAppResourcesDirectoryPath) > -1) {
            var appResourcesRelativePath = path.relative(path.join(this.$projectData.projectDir, constants.APP_FOLDER_NAME, constants.APP_RESOURCES_FOLDER_NAME, platformData.normalizedPlatformName), filePath);
            mappedFilePath = path.join(platformData.platformProjectService.getAppResourcesDestinationDirectoryPath().wait(), appResourcesRelativePath);
        }
        return mappedFilePath;
    };
    ProjectFilesProvider.prototype.isFileExcluded = function (filePath) {
        return !!_.find(ProjectFilesProvider.INTERNAL_NONPROJECT_FILES, function (pattern) { return minimatch(filePath, pattern, { nocase: true }); });
    };
    ProjectFilesProvider.INTERNAL_NONPROJECT_FILES = ["**/*.ts"];
    return ProjectFilesProvider;
})();
exports.ProjectFilesProvider = ProjectFilesProvider;
$injector.register("projectFilesProvider", ProjectFilesProvider);
